==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/CorsPolicyFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import me.snowdrop.istio.api.BoolValue;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import me.snowdrop.istio.api.BoolValueBuilder;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import java.util.List;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import me.snowdrop.istio.api.BoolValueFluent;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import me.snowdrop.istio.api.DurationBuilder;

public interface CorsPolicyFluent<A extends CorsPolicyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAllowCredentials instead.
 * @return The buildable object.
 */
@Deprecated public BoolValue getAllowCredentials();
    public BoolValue buildAllowCredentials();
    public A withAllowCredentials(BoolValue allowCredentials);
    public Boolean hasAllowCredentials();
    public A withNewAllowCredentials(Boolean value);
    public CorsPolicyFluent.AllowCredentialsNested<A> withNewAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> withNewAllowCredentialsLike(BoolValue item);
    public CorsPolicyFluent.AllowCredentialsNested<A> editAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> editOrNewAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> editOrNewAllowCredentialsLike(BoolValue item);
    public A addToAllowHeaders(int index,String item);
    public A setToAllowHeaders(int index,String item);
    public A addToAllowHeaders(String... items);
    public A addAllToAllowHeaders(Collection<String> items);
    public A removeFromAllowHeaders(String... items);
    public A removeAllFromAllowHeaders(Collection<String> items);
    public List<String> getAllowHeaders();
    public String getAllowHeader(int index);
    public String getFirstAllowHeader();
    public String getLastAllowHeader();
    public String getMatchingAllowHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowHeaders(List<String> allowHeaders);
    public A withAllowHeaders(String... allowHeaders);
    public Boolean hasAllowHeaders();
    public A addToAllowMethods(int index,String item);
    public A setToAllowMethods(int index,String item);
    public A addToAllowMethods(String... items);
    public A addAllToAllowMethods(Collection<String> items);
    public A removeFromAllowMethods(String... items);
    public A removeAllFromAllowMethods(Collection<String> items);
    public List<String> getAllowMethods();
    public String getAllowMethod(int index);
    public String getFirstAllowMethod();
    public String getLastAllowMethod();
    public String getMatchingAllowMethod(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowMethods(List<String> allowMethods);
    public A withAllowMethods(String... allowMethods);
    public Boolean hasAllowMethods();
    public A addToAllowOrigin(int index,String item);
    public A setToAllowOrigin(int index,String item);
    public A addToAllowOrigin(String... items);
    public A addAllToAllowOrigin(Collection<String> items);
    public A removeFromAllowOrigin(String... items);
    public A removeAllFromAllowOrigin(Collection<String> items);
    public List<String> getAllowOrigin();
    public String getAllowOrigin(int index);
    public String getFirstAllowOrigin();
    public String getLastAllowOrigin();
    public String getMatchingAllowOrigin(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowOrigin(List<String> allowOrigin);
    public A withAllowOrigin(String... allowOrigin);
    public Boolean hasAllowOrigin();
    public A addToExposeHeaders(int index,String item);
    public A setToExposeHeaders(int index,String item);
    public A addToExposeHeaders(String... items);
    public A addAllToExposeHeaders(Collection<String> items);
    public A removeFromExposeHeaders(String... items);
    public A removeAllFromExposeHeaders(Collection<String> items);
    public List<String> getExposeHeaders();
    public String getExposeHeader(int index);
    public String getFirstExposeHeader();
    public String getLastExposeHeader();
    public String getMatchingExposeHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withExposeHeaders(List<String> exposeHeaders);
    public A withExposeHeaders(String... exposeHeaders);
    public Boolean hasExposeHeaders();
    
/**
 * This method has been deprecated, please use method buildMaxAge instead.
 * @return The buildable object.
 */
@Deprecated public Duration getMaxAge();
    public Duration buildMaxAge();
    public A withMaxAge(Duration maxAge);
    public Boolean hasMaxAge();
    public A withNewMaxAge(Integer nanos,Long seconds);
    public CorsPolicyFluent.MaxAgeNested<A> withNewMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> withNewMaxAgeLike(Duration item);
    public CorsPolicyFluent.MaxAgeNested<A> editMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> editOrNewMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> editOrNewMaxAgeLike(Duration item);

    public interface AllowCredentialsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BoolValueFluent<CorsPolicyFluent.AllowCredentialsNested<N>>{

        
    public N and();    public N endAllowCredentials();
}
    public interface MaxAgeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<CorsPolicyFluent.MaxAgeNested<N>>{

        
    public N and();    public N endMaxAge();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/CorsPolicyFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import me.snowdrop.istio.api.BoolValue;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import me.snowdrop.istio.api.BoolValueBuilder;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import java.util.List;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import me.snowdrop.istio.api.BoolValueFluent;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import me.snowdrop.istio.api.DurationBuilder;

public interface CorsPolicyFluent<A extends CorsPolicyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAllowCredentials instead.
 * @return The buildable object.
 */
@Deprecated public BoolValue getAllowCredentials();
    public BoolValue buildAllowCredentials();
    public A withAllowCredentials(BoolValue allowCredentials);
    public Boolean hasAllowCredentials();
    public A withNewAllowCredentials(Boolean value);
    public CorsPolicyFluent.AllowCredentialsNested<A> withNewAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> withNewAllowCredentialsLike(BoolValue item);
    public CorsPolicyFluent.AllowCredentialsNested<A> editAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> editOrNewAllowCredentials();
    public CorsPolicyFluent.AllowCredentialsNested<A> editOrNewAllowCredentialsLike(BoolValue item);
    public A addToAllowHeaders(int index,String item);
    public A setToAllowHeaders(int index,String item);
    public A addToAllowHeaders(String... items);
    public A addAllToAllowHeaders(Collection<String> items);
    public A removeFromAllowHeaders(String... items);
    public A removeAllFromAllowHeaders(Collection<String> items);
    public List<String> getAllowHeaders();
    public String getAllowHeader(int index);
    public String getFirstAllowHeader();
    public String getLastAllowHeader();
    public String getMatchingAllowHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingAllowHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowHeaders(List<String> allowHeaders);
    public A withAllowHeaders(String... allowHeaders);
    public Boolean hasAllowHeaders();
    public A addNewAllowHeader(String arg1);
    public A addNewAllowHeader(StringBuilder arg1);
    public A addNewAllowHeader(StringBuffer arg1);
    public A addToAllowMethods(int index,String item);
    public A setToAllowMethods(int index,String item);
    public A addToAllowMethods(String... items);
    public A addAllToAllowMethods(Collection<String> items);
    public A removeFromAllowMethods(String... items);
    public A removeAllFromAllowMethods(Collection<String> items);
    public List<String> getAllowMethods();
    public String getAllowMethod(int index);
    public String getFirstAllowMethod();
    public String getLastAllowMethod();
    public String getMatchingAllowMethod(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingAllowMethod(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowMethods(List<String> allowMethods);
    public A withAllowMethods(String... allowMethods);
    public Boolean hasAllowMethods();
    public A addNewAllowMethod(String arg1);
    public A addNewAllowMethod(StringBuilder arg1);
    public A addNewAllowMethod(StringBuffer arg1);
    public A addToAllowOrigin(int index,String item);
    public A setToAllowOrigin(int index,String item);
    public A addToAllowOrigin(String... items);
    public A addAllToAllowOrigin(Collection<String> items);
    public A removeFromAllowOrigin(String... items);
    public A removeAllFromAllowOrigin(Collection<String> items);
    public List<String> getAllowOrigin();
    public String getAllowOrigin(int index);
    public String getFirstAllowOrigin();
    public String getLastAllowOrigin();
    public String getMatchingAllowOrigin(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingAllowOrigin(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAllowOrigin(List<String> allowOrigin);
    public A withAllowOrigin(String... allowOrigin);
    public Boolean hasAllowOrigin();
    public A addNewAllowOrigin(String arg1);
    public A addNewAllowOrigin(StringBuilder arg1);
    public A addNewAllowOrigin(StringBuffer arg1);
    public A addToExposeHeaders(int index,String item);
    public A setToExposeHeaders(int index,String item);
    public A addToExposeHeaders(String... items);
    public A addAllToExposeHeaders(Collection<String> items);
    public A removeFromExposeHeaders(String... items);
    public A removeAllFromExposeHeaders(Collection<String> items);
    public List<String> getExposeHeaders();
    public String getExposeHeader(int index);
    public String getFirstExposeHeader();
    public String getLastExposeHeader();
    public String getMatchingExposeHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingExposeHeader(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withExposeHeaders(List<String> exposeHeaders);
    public A withExposeHeaders(String... exposeHeaders);
    public Boolean hasExposeHeaders();
    public A addNewExposeHeader(String arg1);
    public A addNewExposeHeader(StringBuilder arg1);
    public A addNewExposeHeader(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMaxAge instead.
 * @return The buildable object.
 */
@Deprecated public Duration getMaxAge();
    public Duration buildMaxAge();
    public A withMaxAge(Duration maxAge);
    public Boolean hasMaxAge();
    public A withNewMaxAge(Integer nanos,Long seconds);
    public CorsPolicyFluent.MaxAgeNested<A> withNewMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> withNewMaxAgeLike(Duration item);
    public CorsPolicyFluent.MaxAgeNested<A> editMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> editOrNewMaxAge();
    public CorsPolicyFluent.MaxAgeNested<A> editOrNewMaxAgeLike(Duration item);

    public interface AllowCredentialsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BoolValueFluent<CorsPolicyFluent.AllowCredentialsNested<N>>{

        
    public N and();    public N endAllowCredentials();
}
    public interface MaxAgeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<CorsPolicyFluent.MaxAgeNested<N>>{

        
    public N and();    public N endMaxAge();
}


}
